pub fn decode_pnts(bytes: &[u8]) -> InterchangeResult<PntsFeatureTable>Expand description
Decodes a complete pnts tile into its feature table.
pub fn decode_pnts(bytes: &[u8]) -> InterchangeResult<PntsFeatureTable>Decodes a complete pnts tile into its feature table.