pub fn encode_pnts(table: &PntsFeatureTable) -> InterchangeResult<Vec<u8>>Expand description
Encodes a feature table into a complete pnts tile (header + JSON + binary).
pub fn encode_pnts(table: &PntsFeatureTable) -> InterchangeResult<Vec<u8>>Encodes a feature table into a complete pnts tile (header + JSON + binary).