pub fn export_stage_usda(
stage: &MemoryUsdStageAdapter,
) -> InterchangeResult<String>Expand description
Exports all meshes from a memory stage as a single USDA ASCII document.
pub fn export_stage_usda(
stage: &MemoryUsdStageAdapter,
) -> InterchangeResult<String>Exports all meshes from a memory stage as a single USDA ASCII document.